diff --git a/core_search_facets/src/Plugin/facets/facet_source/CoreNodeSearchFacetSource.php b/core_search_facets/src/Plugin/facets/facet_source/CoreNodeSearchFacetSource.php
index a86d14e..6accd24 100644
--- a/core_search_facets/src/Plugin/facets/facet_source/CoreNodeSearchFacetSource.php
+++ b/core_search_facets/src/Plugin/facets/facet_source/CoreNodeSearchFacetSource.php
@@ -154,6 +154,7 @@ class CoreNodeSearchFacetSource extends FacetSourcePluginBase implements CoreSea
         break;
 
       case 'created':
+      case 'changed':
         $query_types['string'] = 'core_node_search_date';
         break;
 
@@ -236,6 +237,7 @@ class CoreNodeSearchFacetSource extends FacetSourcePluginBase implements CoreSea
       'uid' => $this->t('Author'),
       'langcode' => $this->t('Language'),
       'created' => $this->t('Post date'),
+      'changed' => $this->t('Updated date'),
     ];
   }
 
diff --git a/core_search_facets/src/Tests/IntegrationTest.php b/core_search_facets/src/Tests/IntegrationTest.php
index 067f552..f5bdada 100644
--- a/core_search_facets/src/Tests/IntegrationTest.php
+++ b/core_search_facets/src/Tests/IntegrationTest.php
@@ -3,6 +3,7 @@
 namespace Drupal\core_search_facets\Tests;
 
 use Drupal\facets\Tests\ExampleContentTrait;
+use Drupal\node\Entity\Node;
 
 /**
  * Tests the admin UI with the core search facet source.
@@ -100,9 +101,9 @@ class IntegrationTest extends WebTestBase {
   }
 
   /**
    * Tests the date integration.
    */
-  public function testDate() {
+  public function testCreatedDate() {
     $facet_name = 'Tardigrade';
     $facet_id = 'tardigrade';
 
@@ -136,6 +137,39 @@ class IntegrationTest extends WebTestBase {
   }
 
   /**
+   * Tests the "Updated date" facets.
+   */
+  public function testUpdatedDate() {
+    $facet_name = 'Tardigrade';
+    $facet_id = 'tardigrade';
+
+    $this->addFacet($facet_id, $facet_name, 'changed');
+    $this->createFacetBlock($facet_id);
+    $this->setShowAmountOfResults($facet_id, TRUE);
+
+    // Update the "changed" field value and verify that the date appears as
+    // expected in the facet. The nodes are created on February/March 2016 and
+    // the changed date is December 2016.
+    $node = Node::load(1);
+    $changed_date = new \DateTime('December 3 2016 1PM');
+    $node->changed = $changed_date->format('U');
+    $node->save();
+
+    // Index the content.
+    \Drupal::service('plugin.manager.search')->createInstance('node_search')->updateIndex();
+    search_update_totals();
+
+    $this->drupalGet('search/node', ['query' => ['keys' => 'test']]);
+    $this->assertLink('December 2016 (1)');
+    $this->clickLink('December 2016 (1)');
+    $this->assertResponse(200);
+    $this->assertLink('December 3, 2016 (1)');
+    $this->clickLink('December 3, 2016 (1)');
+    $this->assertResponse(200);
+
+  }
+
+  /**
    * Tests for CRUD operations.
    */
   public function testCrudFacet() {
@@ -100,9 +101,9 @@ class IntegrationTest extends WebTestBase {
 
   /**
-   * Tests the date integration.
+   * Tests the "Created date" facets.
    */
